@@ -20,6 +20,8 @@ val stopb : int
 val notriggers : bool
 val debug : bool
 val debug_cc : bool
+val debug_use : bool
+val debug_tmp : bool
 val debug_uf : bool
 val debug_fm : bool
 val debug_bitv : bool
