@@ -26,27 +26,27 @@ module type RELATION = sig
 end
 
 module type THEORY = sig
-  (**Type of terms of the theorie*)
+  (**Type of terms of the theory*)
   type t
-  (**Type of representants of terms of the theorie*)
+  (**Type of representants of terms of the theory*)
   type r
-  (** Name of the theorie*)
+  (** Name of the theory*)
   val name : string
-  (** return true if the atom is owned by the theorie*)
+  (** return true if the atom is owned by the theory*)
   val is_mine_a : Literal.t -> bool
-  (** return true if the head symbol is owned by the theorie*)
+  (** return true if the head symbol is owned by the theory*)
   val is_mine_hs : Term.t -> bool
-  (** return true if the type is owned by the theorie*)
+  (** return true if the type is owned by the theory*)
   val is_mine_type : t -> bool
 
-  (** Give a normal form of a term of the theorie*)
+  (** Give a normal form of a term of the theory*)
   val normal_form : Literal.t -> Literal.t
-  (** Give a representant of a term of the theorie*)
+  (** Give a representant of a term of the theory*)
   val make : Term.t -> r
   val type_infos : t -> Ty.t
   val embedding : r -> t
 
-  (** Give the leaves of a term of the theorie *)
+  (** Give the leaves of a term of the theory *)
   val leaves : r -> r list
   val subst : r -> r -> t -> r
 
@@ -88,6 +88,7 @@ module type X = sig
   val type_infos : r -> Ty.t
   val compare : r -> r -> int
   val leaves : r -> r list
+  val term_of_leaf : r -> Term.t
   val subst : r -> r -> r -> r
   val solve : r -> r ->  (r * r) list
 
