@@ -148,11 +148,18 @@ let rec term_to_desc env = function
       let ff = envformula env f in 
       let not_ff = 
 	{ff with pp_desc = PPprefix (PPnot,pexp ff.pp_loc ff.pp_desc)} in
-      let aux ff2 = function None -> Some ff2
-        | Some f -> Some (pexp ff.pp_loc (PPinfix (ff2,PPand,pexp ff2.pp_loc f.pp_desc))) in
-      concat_product (aux ff) (concat_product (aux not_ff) [] (term_to_desc env t2.term)) (term_to_desc env t1.term)
+      let aux ff2 = function 
+	  None -> Some ff2
+        | Some f -> 
+	    Some (pexp ff.pp_loc 
+		    (PPinfix (ff2,PPand,pexp ff2.pp_loc f.pp_desc))) 
+      in
+      concat_product (aux ff) 
+	(concat_product (aux not_ff) [] 
+	   (term_to_desc env t2.term)) (term_to_desc env t1.term)
 
-and term env a = List.map (fun (f,t) -> (f,pexp a.tloc t)) (term_to_desc env a.term)
+and term env a = 
+  List.map (fun (f,t) -> (f,pexp a.tloc t)) (term_to_desc env a.term)
 
 and form_to_desc env = function
     (* Pour l'instant on unfold *)
@@ -220,11 +227,11 @@ and envformula env f = pexp f.floc (form_to_desc env f.formula)
 let formula  = envformula {uterm = StringMap.empty ; uformula = StringMap.empty}
 
 let psig_to_pdef (pos,psig) =
-  Logic (pos,false,[psig.pname],
+  Logic (pos,false, false,[psig.pname],
 	 PPredicate (List.map curry_sort_to_type psig.pargs))
 
 let fsig_to_fdef (pos,fsig) =
-  Logic (pos,false,[fsig.fname],
+  Logic (pos,false, false,[fsig.fname],
 	 PFunction ((List.map curry_sort_to_type fsig.fargs),
                     curry_sort_to_type fsig.fres ))
 
