@@ -12,15 +12,16 @@
 (**************************************************************************)
 
 type binop = Plus | Minus | Mult | Div | Modulo | At
+type is_ac = bool
 type t = 
-    Name of Hstring.t
+    Name of Hstring.t * is_ac
   | Int of Hstring.t
   | Rat of Hstring.t
   | Bitv of string
   | Binop of binop 
   | Var of Hstring.t
 
-val name : string -> t
+val name : ?ac:is_ac -> string -> t
 val var : string -> t
 val underscoring : t -> t
 val int : string -> t
@@ -29,6 +30,8 @@ val unit : t
 
 val shat : t
 
+val is_ac : t -> bool
+
 val plus : t
 val minus : t
 val mult : t
@@ -42,11 +45,6 @@ val hash : t -> int
 
 val print : Format.formatter -> t -> unit
 
-(*val is_const : t -> bool
-val value : t -> int*)
-
-val is_c : t -> bool
-val is_ac : t -> bool
 val dummy : t
 val fresh : string -> t
   
