@@ -218,6 +218,7 @@ module Decl = struct
       | TTfalse -> T.faux
       | TTconst (Tint i) -> T.int i
       | TTconst (Treal r) -> T.rat r
+      | TTconst (Tnum n) -> T.rat (Num.string_of_num n)
       | TTconst (Tbitv bt) -> T.bitv bt ty
       | TTconst Tunit -> T.unit
       | TTvar s ->  T.make s [] ty 
@@ -319,8 +320,8 @@ module Logics = struct
     
   let clear () = Hashtbl.clear logics
 
-  let add pf loc n = 
-    let sy = Symbols.name n in
+  let add pf loc ac n = 
+    let sy = Symbols.name n ~ac:ac in
     if Hashtbl.mem logics n then error (SymbAlreadyDefined n) loc;
     Hashtbl.add logics n (sy,pf)
 
@@ -478,7 +479,7 @@ module Triggers = struct
     let m = at_most redondance (if gopt then (mt@mv) else mt) in
     (*(List.map (underscoring_mt bv) m)@
       (List.map (underscoring_mt bv) (List.map List.rev m))*)
-    at_most redondance m
+    at_most redondance m 
 
   let rec vty_ty acc t = 
     let t = Ty.shorten t in
@@ -690,6 +691,7 @@ and type_term_desc env loc = function
   | PPfalse -> TTfalse , Ty.Tbool
   | PPconst (ConstInt n) -> TTconst(Tint n) , Ty.Tint
   | PPconst (ConstReal n) -> TTconst(Treal n) , Ty.Trat
+  | PPconst (ConstNum n) -> TTconst(Tnum n) , Ty.Trat
   | PPconst ConstUnit -> TTconst Tunit , Ty.tunit
   | PPconst (ConstBitv n) -> TTconst(Tbitv n) , Ty.Tbitv (String.length n)
   | PPvar p -> 
@@ -759,6 +761,8 @@ and type_term_desc env loc = function
       TTconst(Tint ("-"^n)) , Ty.Tint
   | PPprefix(PPneg, {pp_desc=PPconst (ConstReal n)}) -> 
       TTconst(Treal ("-"^n)) , Ty.Trat
+  | PPprefix(PPneg, {pp_desc=PPconst (ConstNum n)}) -> 
+      TTconst(Tnum (Num.minus_num n)) , Ty.Trat
   | PPprefix(PPneg, e) -> 
       begin
 	let te = type_term env e in
@@ -812,7 +816,7 @@ let make_le_or_lt p l =
     let _ = Builtin.is_builtin s in 
     (match p with PPle -> TAle l | PPlt -> TAlt l | _ -> assert false)
   with Not_found -> 
-    let s = Symbols.Name (Hstring.make s) in
+    let s = Symbols.name s in (* XXX *)
     let t = {tt_desc=TTapp(s,l);tt_ty=Ty.Tbool} in 
     TAeq[t;{tt_desc=TTtrue;tt_ty=Ty.Tbool}]
 
@@ -881,7 +885,8 @@ let rec type_form env f = match f.pp_desc with
 			let desc = TTinfix(tt2,Symbols.minus,one) in
 			TFatom 
 			  (make_le_or_lt PPle [tt1;{tt2 with tt_desc=desc}])
-		    | _ -> TFatom (make_le_or_lt PPle [tt1;tt2])
+		    | _ -> 
+			TFatom (make_le_or_lt PPlt [tt1;tt2])
 		end
 	    | PPgt -> 
 		begin
@@ -909,7 +914,8 @@ let rec type_form env f = match f.pp_desc with
 	  | PPiff ->TFop(OPiff,[f1;f2])
 	  | _ -> assert false), Sy.union fv1 fv2)
       end
-  | PPprefix(PPnot,f) -> let f,fv = type_form env f in TFop(OPnot,[f]),fv
+  | PPprefix(PPnot,f) -> 
+      let f,fv = type_form env f in TFop(OPnot,[f]),fv
   | PPif(f1,f2,f3) -> 
       let f1 = type_term env f1 in
       let f2,fv2 = type_form env f2 in
@@ -1006,6 +1012,7 @@ let rec intro_hypothesis env bnot f =
 	let env , f = elim_toplevel_forall env bnot f in
 	env , [] , f
 
+(*
 let rec move_up f = 
   { f with pp_desc = move_up_desc f.pp_desc }
 
@@ -1028,13 +1035,13 @@ and move_up_desc = function
       PPforall(lv1,t1,[],fd)
 	
     | f -> f
-  
+*)
 
 let fresh_axiom_name = 
   let cpt = ref 0 in fun () -> incr cpt; "_H"^(string_of_int !cpt)
 
 let rec make_pred loc trs f = function
-    [] -> f
+    [] ->  f
   | [x,t] ->
       { pp_desc = PPforall([x],t,trs,f) ; pp_loc = loc }
   | (x,t)::l -> 
@@ -1054,8 +1061,8 @@ let check_duplicate_params l =
 let type_decl acc d = 
   try
     match d with
-	Logic (loc,ext,lp, ty) -> 
-	  List.iter (Logics.add (Profile.of_logictype ty) loc) lp;
+	Logic (loc,ac, ext, lp, ty) -> 
+	  List.iter (Logics.add (Profile.of_logictype ty) loc ac) lp;
 	  TLogic(loc,ext,lp,ty)::acc
       | Axiom(loc,name,f) -> 
 	  let f,_ = type_form Env.empty f in 
@@ -1064,7 +1071,8 @@ let type_decl acc d =
       | Goal(loc,n,f) -> 
 	  (*let f = move_up f in*)
 	  let env , axioms , goal = 
-	    intro_hypothesis Env.empty (not (!smtfile or !satmode)) f in
+	    intro_hypothesis Env.empty 
+	      (not (!smtfile or !satmode)) f in
 	  let axioms =
 	    List.fold_left
 	      (fun acc f ->
@@ -1085,7 +1093,7 @@ let type_decl acc d =
 	    | _ -> PPredicate l 
 	  in
 	  let l = List.map (fun (_,x,t) -> (x,t)) l in
-	  Logics.add (Profile.of_logictype ty) loc n;
+	  Logics.add (Profile.of_logictype ty) loc false n; (* TO DO *)
 	  let lvar = List.map (fun (x,_) -> {pp_desc=PPvar x;pp_loc=loc}) l in
 	  let p = {pp_desc=PPapp(n,lvar) ; pp_loc=loc } in
 	  let infix = match d with Function_def _ -> PPeq | _ -> PPiff in
@@ -1104,10 +1112,24 @@ let type_decl acc d =
     Loc.report loc; printf "Warning: %a@." report e;
     TWarning(loc)::acc
 
-let file l = 
-  Logics.clear();
-  Types.clear();
-  List.rev (List.fold_left type_decl [] l) 
+let split_file l = 
+  let acc, ret = 
+    List.fold_left
+      (fun (acc,ret) x -> 
+	 match x with 
+	     Goal _ -> acc, (x::acc)::ret
+	   | _ -> x::acc, ret) ([],[]) l
+  in 
+  let r = if acc=[] then ret else acc::ret in
+  List.rev_map List.rev r
+
+let file f = 
+  List.rev 
+    (List.fold_left 
+       (fun acc l ->
+	  Logics.clear();
+	  Types.clear();
+	  (List.rev (List.fold_left type_decl [] l))::acc) [] (split_file f))
 
 let make_cnf l = 
   Decl.clear ();
@@ -1117,6 +1139,7 @@ let make_cnf l =
     (fun (d,b) -> match d with
 	 TAxiom(loc,name,f) -> Decl.push_assume f name loc b
        | TGoal(loc,n,f) -> Decl.push_query n f loc
+       | TPredicate_def(loc,n,[],f) -> Decl.push_assume f n loc b
        | TPredicate_def(loc,n,_,f) -> Decl.push_preddef f n loc b
        | TFunction_def(loc,n,_,_,f) -> Decl.push_assume f n loc b
        | _ -> ()) l;
