@@ -22,7 +22,7 @@ type tdecl =
 
 val make_cnf : (Why_ptree.typed_decl * bool) list -> tdecl Queue.t
 
-val file : Why_ptree.file -> Why_ptree.typed_decl list
+val file : Why_ptree.file -> Why_ptree.typed_decl list list
 
 val report : Format.formatter -> error -> unit
 
